@@ -1,12 +1,13 @@
-__END__
+package HTML::Merge;
+1;
 
 =head1 NAME
 
-HTML::Merge - Embedded HTML/SQL/Perl Copyright (c) 1999 - 2004 Raz Information Systems Ltd.
+HTML::Merge - Embedded HTML/SQL/Perl system.
 
 =head1 INSTALLATION
 
-After installing the package, activate B<mergecreateinstance> to create an instance in your cgi-bin (or modperl) directory.
+After installing the package, activate B<mergecreateinstance> to create an instance in your cgi-bin (or mod_perl) directory.
 Follow the directions you get from B<mergecreateinstance> in order to configure
 your web server.
 
@@ -24,7 +25,9 @@ You must edit the merge.conf created for you.
 
 =head1 DESCRIPTION
 
-Merge is an embedded HTML/Perl/SQL tool used to create dynamic web content.
+Merge is an embedded HTML/Perl/SQL tool for creating dynamic web content.
+merge.pl compiles HTML with embeded Perl to Perl CGI programs and run them.
+
 All Merge pages are referred to by B<cgi-bin-dir>/merge.pl?template=B<file.html>
 
 (Important: file.html is a HTML template that located in a directory you choose
@@ -90,13 +93,13 @@ Toolbox written by Eial Solodki.
 
 Testing & documentation by Noam cassif.
 
-New test & version 3.46 - Gabor Szabo.
+New test & version 3.46 - Gabor Szabo and Oded Resnik.
 
 =back
 
 =head1 COPYRIGHT
 
-Copyright (c) 1999 - 2004 Raz Information Systems Ltd.
+Copyright (c) 1999 - 2005 Raz Information Systems Ltd.
 http://www.raz.co.il
 
 This package is distributed under the same terms as Perl itself, see the 
